@@ -14,7 +14,7 @@ use Carp ();
 use Env qw( @PERL5LIB );
 
 # ABSTRACT: Clustericious command to start a Clustericious application
-our $VERSION = '1.19'; # VERSION 
+our $VERSION = '1.20'; # VERSION 
 
 
 has description => <<EOT;
@@ -74,7 +74,7 @@ sub run {
     }
     elsif(%conf)
     {
-      Carp::carp("argumenst specified withouth 'args' option is deprecated and will be removed on or after February 29, 2016");
+      Carp::carp("arguments specified withouth 'args' option is deprecated and will be removed on or after February 29, 2016");
       # THIS IS RETARDED AND SHOULD BE DEPRECATED
       # if it starts with a dash, leave it alone, else add two dashes
       my %args = mesh
@@ -105,7 +105,7 @@ Clustericious::Command::start - Clustericious command to start a Clustericious a
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 SYNOPSIS
 
