@@ -6,8 +6,7 @@ use Log::Log4perl qw(get_logger :levels);
 use Getopt::Long;
 
 # ABSTRACT: Simple Command Line Interface for Log4perl
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.20'; # VERSION
 
 
 my %init;     # logconfig, loginit, logfile, logcategory, noinit
@@ -188,7 +187,7 @@ Clustericious::Log::CommandLine - Simple Command Line Interface for Log4perl
 
 =head1 VERSION
 
-version 1.28_01
+version 1.20
 
 =head1 SYNOPSIS
 
@@ -214,8 +213,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
