@@ -17,7 +17,7 @@ use YAML::XS ();
 use File::Temp qw( tempdir );
 
 # ABSTRACT: Test Clustericious commands
-our $VERSION = '1.19'; # VERSION
+our $VERSION = '1.20'; # VERSION
 
 
 our @EXPORT      = qw( extract_data mirror requires run_ok generate_port note_file clean_file create_symlink );
@@ -91,7 +91,7 @@ sub extract_data
 {
   my(@values) = @_;
   my $caller = caller;
-  Mojo::Loader::load_class $caller;
+  Mojo::Loader::load_class($caller) unless $caller eq 'main';
   my $all = Mojo::Loader::data_section $caller;
   
   my $tb = __PACKAGE__->builder;
@@ -343,7 +343,7 @@ Test::Clustericious::Command - Test Clustericious commands
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 SYNOPSIS
 
